==> finit_4.1.orig.tar.xz: finit-4.1/src/cgroup.h <==
/* Finit control group support functions
 *
 * Copyright (c) 2019-2021  Joachim Wiberg <troglobit@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#ifndef FINIT_CGROUP_H_
#define FINIT_CGROUP_H_

#include <uev/uev.h>

struct cgroup {
	char name[16];
	char cfg[128];
};

void cgroup_mark_all(void);
void cgroup_cleanup (void);

int  cgroup_add     (char *name, char *cfg, int protected);
int  cgroup_del     (char *dir);
void cgroup_config  (void);

void cgroup_init    (uev_ctx_t *ctx);

int  cgroup_user    (char *name, int pid);
int  cgroup_service (char *name, int pid, struct cgroup *cg);

#endif /* FINIT_CGROUP_H_ */

==> finit_4.2.orig.tar.xz: finit-4.2/src/cgroup.h <==
/* Finit control group support functions
 *
 * Copyright (c) 2019-2021  Joachim Wiberg <troglobit@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#ifndef FINIT_CGROUP_H_
#define FINIT_CGROUP_H_

#include <uev/uev.h>

struct cgroup {
	char name[16];
	char cfg[128];
};

void cgroup_mark_all(void);
void cgroup_cleanup (void);

int  cgroup_add     (char *name, char *cfg, int is_protected);
int  cgroup_del     (char *dir);
void cgroup_config  (void);

void cgroup_init    (uev_ctx_t *ctx);

int  cgroup_user    (char *name, int pid);
int  cgroup_service (char *name, int pid, struct cgroup *cg);

#endif /* FINIT_CGROUP_H_ */
